Learn R Programming

TREDesigns (version 1.0.1)

BtRED: Balanced Ternary Residual Effect Designs for Prime Number of Treatments

Description

This function generates a class of balanced ternary residual effect designs (BTREDs) for a prime number of treatments (v), where (v >= 5) with p periods, determined as (v+3)/2, and n sequences, take the value v(v-1).

Usage

BtRED(v)

Value

It returns a new class of BTREDs along with its parameters, Information Matrix (C), Average Variance Factor (AVF), and Canonical Efficiency Factor (CEF) for both treatment and residual effects.

Arguments

v

Prime Number of Treatments, v ( >= 5)

Examples

Run this code
library(TREDesigns)
BtRED(v = 7)

Run the code above in your browser using DataLab