Learn R Programming

TREDesigns (version 1.0.1)

PBtRED3: Partially Balanced Ternary Residual Effect Designs for Number of Treatments, v ( >= 5)

Description

This function generates a new class of partially balanced ternary residual effect designs (PBTREDs) for all treatments, v (>= 5) in periods, p = (v+3)/2 if v is odd, otherwise p = (v+2)/2, and the number of sequences, n = 2v.

Usage

PBtRED3(v)

Value

It returns a new class of PBTREDs along with its parameters, Information matrix (C), Average Variance Factor (AVF), and Canonical Efficiency Factor (CEF) for both treatment and residual effects.

Arguments

v

Number of treatments (>= 5)

Examples

Run this code
library(TREDesigns)
PBtRED3(v = 5)

Run the code above in your browser using DataLab